<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        title="选择流转签署人"
        width="500px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="部门:" prop="deptIds" >
          <el-cascader
              style="width: 100%"
              clearable
              placeholder="请选择部门"
              v-model="state.deptIds"
              :options="state.options"
              @change="selectValue"
              :props="{ multiple:true, expandTrigger: 'hover', value: 'deptId',label: 'deptName',emitPath: false}">
          </el-cascader>
        </el-form-item>
        <el-form-item label="签署人:" prop="initiaiUsers" >
          <el-select
              clearable
              v-model="state.initiaiUsers"
              filterable
              remote
              multiple
              reserve-keyword
              placeholder="请输入签署人名称"
              remote-show-suffix
              @change="changeUser"
              :remote-method="(val)=>getUserList(val,state.deptIds)"
              style=" width:100%"
              value-key="userId"
          >
            <el-option
                v-for="item in state.userList"
                :key="item.userId"
                :label="item.nickName"
                :value="item"
            />
          </el-select>
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认流转</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";
import {signFlow} from "@/api/signAgreement/signProject";
import {getInfo} from "@/api/login";
import {userListByDept} from "@/api/signAgreement/template";

const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);

const state = reactive({
  form: {
    itemId: null,
    initiaiUserId:null,
    userDept: []
  },
  user: {},
  options: [],
  userList: [],
  // formRules:{
  //   deptIds: [{ required: true, trigger: "blur", message:'请选择部门' }],
  //   initiaiUsers: [{ required: true, trigger: "blur", message:'请选择签署人' }],
  // },
  deptIds: [],
  initiaiUsers: []
})


const openDialog = async (value) => {
  await getDept()
  await getUserInfo()
  state.form.itemId = value.id
  dialogVisible.value = true;
}
const selectValue = (val) => {
  state.userList = []
  state.form.initiaiUserId = null
  state.initiaiUsers = []
  state.form.userDept = []
  getUserList("",val)

}
const changeUser = (val) =>{
  const userIds = val.map(item => item.userId)
  state.form.initiaiUserId = userIds.join(',')
  state.form.userDept = val.map(i => i.userId + '_' + i.deptId)
}
const getDept = () => {
  listDept().then(response => {
    state.options = proxy.handleTree(response.data, "deptId",'parentId','children');
  });
}

const getUserInfo = async () => {
  const res = await getInfo()
  if(res.code == 200){
    state.user = res.user
  }else{
    ElMessage.warning(res.message)
  }
}


const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      data.userId = state.user.userId
      data.userName = state.user.userName
      data.deptId = state.user.deptId
      data.deptName = state.user.dept.deptName
      if(data.initiaiUserId == null) {
        ElMessage.warning('请选择签署人')
        return;
      }
      const res = await signFlow(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '流转成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    itemId: null,
    initiaiUserId:null,
    userDept: []
  }
  state.deptIds = []
  state.initiaiUsers = []
}
const getUserList = async (val,deptId)=>{
  if(deptId.length ==0 || deptId == null){
    // ElMessage.warning("请选择部门！")
    return;
  }
  if(val != ""){
    const queryParams = {
      deptId: deptId,
      nickName: val,
    }
    const res = await userListByDept(queryParams)
    if (res.code == 200) {
      state.userList = res.rows.map(item => {
        return {
          ...item,
          nickName: item.nickName +  ' ( ' + item.dept.deptName + ' ) '
        }
      })
    } else {
      ElMessage.warning(res.message)
    }
  }else {
    const queryParams = {
      pageNum: 1,
      pageSize: 10,
      deptId: deptId
    }
    const res = await userListByDept(queryParams)
    if (res.code == 200) {
      state.userList = res.rows.map(item => {
        return {
          ...item,
          nickName: item.nickName +  ' ( ' + item.dept.deptName + ' ) '
        }
      })
    } else {
      ElMessage.warning(res.message)
    }
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
